'use strict';

var _getIterator = require('babel-runtime/core-js/get-iterator')['default'];

var _Object$keys = require('babel-runtime/core-js/object/keys')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

Object.defineProperty(exports, '__esModule', {
	value: true
});
exports['default'] = isomorph;
exports.assets = assets;

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _pluginsWriteStats = require('./plugins/write stats');

var _pluginsWriteStats2 = _interopRequireDefault(_pluginsWriteStats);

var _pluginsNotifyStats = require('./plugins/notify stats');

var _pluginsNotifyStats2 = _interopRequireDefault(_pluginsNotifyStats);

// using ES6 template strings
// https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/template_strings

function isomorph(webpack_configuration) {
	var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

	if (!options.assets) {
		throw new Error('You must specify "assets" parameter');
	}

	var regular_expressions = {};

	// will be used with write_stats plugin
	var assets = {};

	var _iteratorNormalCompletion = true;
	var _didIteratorError = false;
	var _iteratorError = undefined;

	try {
		for (var _iterator = _getIterator(_Object$keys(options.assets)), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
			var assets_type = _step.value;

			var description = options.assets[assets_type];

			regular_expressions[assets_type] = new RegExp('\\.(' + description.extensions.join('|') + ')$');

			webpack_configuration.modules.loaders.push({
				test: regular_expressions[assets_type],
				include: description.paths || [description.path],
				loaders: description.loaders
			});

			assets[assets_type] = {
				regular_expression: regular_expressions[assets_type]
			};
		}
	} catch (err) {
		_didIteratorError = true;
		_iteratorError = err;
	} finally {
		try {
			if (!_iteratorNormalCompletion && _iterator['return']) {
				_iterator['return']();
			}
		} finally {
			if (_didIteratorError) {
				throw _iteratorError;
			}
		}
	}

	if (!webpack_configuration.output.path) {
		throw new Error('You must specify "configuration.output.path" in your webpack configuration');
	}

	if (!webpack_configuration.output.publicPath) {
		throw new Error('You must specify "configuration.output.publicPath" in your webpack configuration');
	}

	var webpack_stats_path = webpack_stats_path(webpack_configuration);

	// add webpack plugins

	// write webpack compiled files' names to a special .json file
	// (this will be used later to fetch these files from server)
	function write_stats_plugin() {
		this.plugin('done', function (stats) {
			_pluginsWriteStats2['default'].call(this, stats, {
				environment: 'development',
				output: webpack_stats_path,
				assets: assets
			});
		});
	}

	if (options.development) {
		configuration.plugins = configuration.plugins.concat(
		// outputs stats info to the console
		function () {
			this.plugin('done', _pluginsNotifyStats2['default']);
		}, write_stats_plugin);
	} else {
		configuration.plugins = configuration.plugins.concat(write_stats_plugin);
	}

	return webpack_configuration;
}

function webpack_stats_path(webpack_configuration) {
	return _path2['default'].resolve(webpack_configuration.output.path, 'webpack-stats.json');
}

function assets(webpack_configuration) {
	return require(webpack_stats_path(webpack_configuration));
}
//# sourceMappingURL=index.js.map